import io
import os
import re

import setuptools

def get_long_description():
    base_dir = os.path.abspath(os.path.dirname(__file__))
    with io.open(os.path.join(base_dir, "README.md"), encoding="utf-8") as f:
        return f.read()

def get_requirements():
    current_dir = os.path.abspath(os.path.dirname(__file__))
    requirements_file = os.path.join(current_dir, "requirements.txt")
    with io.open(requirements_file, encoding="utf-8") as f:
        return f.read().splitlines()


def get_version():
    current_dir = os.path.abspath(os.path.dirname(__file__))
    version_file = os.path.join(current_dir, "bytetracker", "__init__.py")
    with io.open(version_file, encoding="utf-8") as f:
        return re.search(r'^__version__ = [\'"]([^\'"]*)[\'"]', f.read(), re.M).group(1)


setuptools.setup(
    name="bytetracker",
    version=get_version(),
    author="kadirnar",
    license="MIT",
    description="Packaged version of the ByteTrack repository",
    long_description=get_long_description(),
    long_description_content_type="text/markdown",
    url="https://github.com/kadirnar/bytetrack-pip",
    packages=setuptools.find_packages(),
    python_requires=">=3.5",
    install_requires=get_requirements(),
    include_package_data=True,
    extras_require={
        "dev": ["black==21.7b0", "flake8==3.9.2", "isort==5.9.2"],
    },
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Topic :: Software Development :: Libraries",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Education",
        "Topic :: Scientific/Engineering",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
    ],
    keywords="machine-learning, deep-learning, pytorch, vision, image-classification, object-detection, object-tracking, tracker, bytetrack",
)
